@@ -1,21 +1,25 @@
 from datetime import datetime
+from dateutil.tz import tzutc
 import logging
 import json
 
 from requests.auth import HTTPBasicAuth
-import requests
+from requests import sessions
+
+_session = sessions.Session()
 
 
 def post(write_key, **kwargs):
     """Post the `kwargs` to the API"""
     log = logging.getLogger('segment')
     body = kwargs
+    body["sentAt"] = datetime.utcnow().replace(tzinfo=tzutc()).isoformat()
     url = 'https://api.segment.io/v1/batch'
     auth = HTTPBasicAuth(write_key, '')
     data = json.dumps(body, cls=DatetimeSerializer)
     headers = { 'content-type': 'application/json' }
     log.debug('making request: %s', data)
-    res = requests.post(url, data=data, auth=auth, headers=headers, timeout=15)
+    res = _session.post(url, data=data, auth=auth, headers=headers, timeout=15)
 
     if res.status_code == 200:
         log.debug('data uploaded successfully')
@@ -46,4 +50,4 @@ class DatetimeSerializer(json.JSONEncoder):
         if isinstance(obj, datetime):
             return obj.isoformat()
 
-        return json.JSONEncoder.default(self, obj)
\ No newline at end of file
+        return json.JSONEncoder.default(self, obj)
